@@ -223,6 +223,13 @@ static int buf_write(Stream_t *Stream, char *buf, off_t start, size_t len)
 	}
 
 	disk_ptr = This->buf + offset;
+
+	/* extend if we write beyond end */
+	if(offset + len > This->cur_size) {
+		len -= (offset + len) % This->sectorSize;
+		This->cur_size = len + offset;
+	}
+
 	memcpy(disk_ptr, buf, len);
 	if(!This->dirty || disk_ptr - This->buf < This->dirty_pos)
 		This->dirty_pos = ROUND_DOWN(offset, This->sectorSize);
@@ -236,11 +243,6 @@ static int buf_write(Stream_t *Stream, char *buf, off_t start, size_t len)
 		exit(1);
 	}
 
-	if(This->dirty_end + This->current >  204784  * 1024) {
-		fprintf(stderr, "Too big for the test disk\n");
-		exit(1);
-	}
-
 	This->dirty = 1;
 	return len;
 }
