@@ -26,12 +26,14 @@ int copyfile(Stream_t *Source, Stream_t *Target)
 
 	pos = 0;
 	GET_DATA(Source, 0, &len, 0, 0);
-	while(pos < len){
+	while(1){
 		ret = READS(Source, buffer, pos, 8*16384);
 		if (ret < 0 ){
 			perror("file read");
 			return -1;
 		}
+		if(!ret)
+			break;
 		if(got_signal)
 			return -1;
 		if (ret == 0)
