@@ -171,7 +171,7 @@ static inline int set_parameters(int fd, struct generic_floppy_struct *floppy,
 struct device devices[] = {
 #ifdef CPU_mips     /* for Siemens Nixdorf's  SINIX-N/O (mips) 5.4x SVR4 */
 	{ "/dev/at/flp/f0t",    'A', FHD312},
-	{ "/dev/fd0",           'A', FGENFD},
+	{ "/dev/fd0",           'A', GENFD},
 #else
 #ifdef CPU_i386     /* for Siemens Nixdorf's  SINIX-D/L (intel) 5.4x SVR4 */
 	{ "/dev/fd0135ds18",	'A', FHD312},
@@ -206,7 +206,7 @@ struct device devices[] = {
 	{"/dev/rdsk/f13dt",	'B', FDD312},
 	{"/dev/rdsk/0p1",	'C', GENHD},
 	{"/usr/vpix/defaults/C:",'D',12, 0, 0, 0, 0,8704L,DEF_ARG0},
-	{"$HOME/vpix/C:", 	'E', 12, 0, 0, 0, 0,8704L,DEF_ARG},
+	{"$HOME/vpix/C:", 	'E', 12, 0, 0, 0, 0,8704L,MDEF_ARG},
 };
 #else
 /* contributed by larry.jones@sdrc.com (Larry Jones) */
@@ -301,7 +301,7 @@ char *getVoldName(struct device *dev, char *name)
 {
 	char *rname;
   
-	if(!IS_VOLD(dev))
+	if(!SHOULD_USE_VOLD(dev))
 		return name;
 
 	/***
@@ -309,15 +309,17 @@ char *getVoldName(struct device *dev, char *name)
 	 * daemon and libraries to get the correct device name...
 	 ***/
 	rname = media_findname(name);
+#ifdef HAVE_MEDIA_OLDALIASES
 	if (rname == NULL) {
 		if ((alias_name = media_oldaliases(name)) != NULL)
 			rname = media_findname(alias_name);
-		if (rname == NULL) {
-			fprintf(stderr, 
+	}
+#endif
+	if (rname == NULL) {
+		fprintf(stderr, 
 				"No such volume or no media in device: %s.\n", 
 				name);
-			exit(1);
-		}
+		exit(1);
 	}
 	return rname;
 }
@@ -423,10 +425,10 @@ struct device devices[] = {
 #ifdef OS_irix
 #define predefined_devices
 struct device devices[] = {
-  { "/dev/rdsk/fds0d2.3.5hi",	'A', HD312},
-  { "/dev/rdsk/fds0d2.3.5",	'A', DD312},
-  { "/dev/rdsk/fds0d2.96",	'A', HD514},
-  {"/dev/rdsk/fds0d2.48",	'A', DD514},
+  { "/dev/rdsk/fds0d2.3.5hi",	'A', FHD312},
+  { "/dev/rdsk/fds0d2.3.5",	'A', FDD312},
+  { "/dev/rdsk/fds0d2.96",	'A', FHD514},
+  {"/dev/rdsk/fds0d2.48",	'A', FDD514},
 };
 #endif /* OS_irix */
 
@@ -529,14 +531,6 @@ struct device devices[] = {
 
 #ifdef OS_linux
 
-#include <linux/fdreg.h>
-#include <linux/major.h>
-#include <linux/fs.h>
-
-#ifndef major
-#define major(x) MAJOR(x)
-#endif
-
 const char *error_msg[22]={
 "Missing Data Address Mark",
 "Bad cylinder",
@@ -737,6 +731,18 @@ static inline int get_parameters(int fd, struct floppy_struct *floppy)
 #endif /* linux */
 
 
+/* OS/2, gcc+emx */
+#ifdef __EMX__
+#define predefined_devices
+struct device devices[] = {
+  {"A:", 'A', GENFD},
+  {"B:", 'B', GENFD},
+};
+#define INIT_NOOP
+#endif
+
+
+
 /*** /jes -- for D.O.S. 486 BL DX2/80 ***/
 #ifdef OS_freebsd
 #define predefined_devices
@@ -768,7 +774,7 @@ struct device devices[] = {
 
 #define predefined_devices
 struct device devices[] = {
-	{"/dev/rfp020",		'A', 12,O_NDELAY,40,2, 9, 0, DEF_ARG},
+	{"/dev/rfp020",		'A', 12,O_NDELAY,40,2, 9, 0, MDEF_ARG},
 	{"/usr/bin/DOS/dvd000", 'C', GENFD},
 };
 
@@ -1000,7 +1006,7 @@ int init_geom(int fd, struct device *dev, struct device *orig_dev,
 const int nr_const_devices = sizeof(const_devices) / sizeof(*const_devices);
 #else
 struct device devices[]={
-	{"/dev/fd0", 'A', 0, O_EXCL, 0,0, 0,0, DEF_ARG},
+	{"/dev/fd0", 'A', 0, O_EXCL, 0,0, 0,0, MDEF_ARG},
 	/* to shut up Ultrix's native compiler, we can't make this empty :( */
 };
 const nr_const_devices = 0;
