@@ -1,10 +1,25 @@
 #ifdef OS_linux
 
 #include <sys/types.h>
+
+#ifdef HAVE_SYS_SYSMACROS_H
+
+#include <sys/sysmacros.h>
+#define MAJOR(dev) major(dev)
+#define MINOR(dev) minor(dev)
+
+#else
+ 
+#include <linux/fs.h>        /* get MAJOR/MINOR from Linux kernel */
+#ifndef major
+#define major(x) MAJOR(x)
+#endif
+
+#endif /* HAVE_SYS_SYSMACROS_H */
+
 #include <linux/fd.h>
 #include <linux/fdreg.h>
 #include <linux/major.h>
-#include <linux/fs.h>
 
 
 typedef struct floppy_raw_cmd RawRequest_t;
