@@ -96,6 +96,13 @@ int isHashed(dirCache_t *cache, char *name)
 	return ret;
 }
 
+void checkXYZ(dirCache_t *cache)
+{
+	if(cache->entries[2])
+		printf(" at 2 = %d\n", cache->entries[2]->beginSlot);
+}
+
+
 int growDirCache(dirCache_t *cache, int slot)
 {
 	if( cache->nr_entries <= slot) {
