@@ -20,7 +20,7 @@ const char *expand(const char *input, char *ans)
 	if (*input == '\0')
 		return("");
 					/* any thing to expand? */
-	if (!strpbrk(input, "$*(){}[]\\?~")) {
+	if (!strpbrk(input, "$*(){}[]\\?`~")) {
 		strcpy(ans, input);
 		return(ans);
 	}
