@@ -579,7 +579,9 @@ static int check_media_type(Fs_t *This, struct bootsector *boot,
 	    (address[0] != 0xf9 || boot->descr != 0xf0)) ||
 	   address[0] < 0xf0) {
 		fprintf(stderr,
-			"Bad media type, probably non-MSDOS disk\n");
+			"Bad media types %02x/%02x, probably non-MSDOS disk\n", 
+				address[0],
+				boot->descr);
 		return -1;
 	}
 
@@ -871,36 +873,6 @@ unsigned int getStart(Stream_t *Dir, struct directory *dir)
 	return first;
 }
 
-static unsigned int _countBlocks(Fs_t *This, unsigned int block)
-{
-	unsigned int blocks;
-
-	blocks = 0;
-	while (block <= This->last_fat && block != 1 && block) {
-		blocks++;
-		block = fatDecode(This, block);
-	}
-	return blocks;
-}
-
-unsigned int countBlocks(Stream_t *Dir, unsigned int block)
-{
-	Stream_t *Stream = GetFs(Dir);
-	DeclareThis(Fs_t);
-
-	return _countBlocks(This, block);
-}
-
-size_t countBytes(Stream_t *Dir, unsigned int block)
-{
-	Stream_t *Stream = GetFs(Dir);
-	DeclareThis(Fs_t);
-
-	return _countBlocks(This, block) * 
-		This->sector_size * 
-		This->cluster_size;
-}
-
 int fs_free(Stream_t *Stream)
 {
 	DeclareThis(Fs_t);
