@@ -32,7 +32,7 @@ int unix_loop(Stream_t *Stream, MainParam_t *mp, char *arg, int follow_dir_link)
 	mp->File = NULL;
 	mp->direntry = NULL;
 	mp->unixSourceName = arg;
-	/*	mp->dir.attr = 0x20;*/
+	/*	mp->dir.attr = ATTR_ARCHIVE;*/
 	mp->loop = _unix_loop;
 	if((mp->lookupflags & DO_OPEN)){
 		mp->File = SimpleFileOpen(0, 0, arg, O_RDONLY, 0, 0, 0);
@@ -50,6 +50,7 @@ int unix_loop(Stream_t *Stream, MainParam_t *mp, char *arg, int follow_dir_link)
 			struct stat buf;
 
 			FREE(&mp->File);
+#ifndef __EMX__
 			if(!follow_dir_link &&
 			   lstat(arg, &buf) == 0 &&
 			   S_ISLNK(buf.st_mode)) {
@@ -60,7 +61,7 @@ int unix_loop(Stream_t *Stream, MainParam_t *mp, char *arg, int follow_dir_link)
 					arg);
 				return 0;				
 			}
-
+#endif
 			if(! (mp->lookupflags & ACCEPT_DIR))
 				return 0;
 			mp->File = OpenDir(Stream, arg);
@@ -135,7 +136,7 @@ static int handle_leaf(direntry_t *direntry, MainParam_t *mp,
 	}
 
 	mp->direntry = direntry;
-	if(direntry->dir.attr & 0x10) {
+	if(IS_DIR(direntry)) {
 		if(mp->lookupflags & (DO_OPEN | DO_OPEN_DIRS))
 			MyFile = mp->File = OpenFileByDirentry(direntry);
 		ret = mp->dirCallback(direntry, mp);
@@ -164,14 +165,14 @@ static int _dos_loop(Stream_t *Dir, MainParam_t *mp, const char *filename)
 		if(!checkForDot(mp->lookupflags,entry.name)) {
 			MyFile = 0;
 			if((mp->lookupflags & DO_OPEN) ||
-			   ((entry.dir.attr | 0x10) && 
+			   (IS_DIR(&entry) && 
 			    (mp->lookupflags & DO_OPEN_DIRS))) {
 				MyFile = mp->File = OpenFileByDirentry(&entry);
 			}
 			if(got_signal)
 				break;
 			mp->direntry = &entry;
-			if(entry.dir.attr & 0x10)
+			if(IS_DIR(&entry))
 				ret |= mp->dirCallback(&entry,mp);
 			else
 				ret |= mp->callback(&entry, mp);
