@@ -31,20 +31,20 @@ static int attrib_file(direntry_t *entry, MainParam_t *mp)
 static int view_attrib(direntry_t *entry, MainParam_t *mp)
 {
 	printf("  ");
-	if(entry->dir.attr & 0x20)
+	if(IS_ARCHIVE(entry))
 		putchar('A');
 	else
 		putchar(' ');
 	fputs("  ",stdout);
-	if(entry->dir.attr & 0x4)
+	if(IS_SYSTEM(entry))
 		putchar('S');
 	else
 		putchar(' ');
-	if(entry->dir.attr & 0x2)
+	if(IS_HIDDEN(entry))
 		putchar('H');
 	else
 		putchar(' ');
-	if(entry->dir.attr & 0x1)
+	if(IS_READONLY(entry))
 		putchar('R');
 	else
 		putchar(' ');
@@ -59,15 +59,15 @@ static int concise_view_attrib(direntry_t *entry, MainParam_t *mp)
 {
 	Arg_t *arg=(Arg_t *) mp->arg;
 
-	if(entry->dir.attr & 0x20)
+	if(IS_ARCHIVE(entry))
 		putchar('A');
-	if(entry->dir.attr & 0x10)
+	if(IS_DIR(entry))
 		putchar('D');	
-	if(entry->dir.attr & 0x4)
+	if(IS_SYSTEM(entry))
 		putchar('S');
-	if(entry->dir.attr & 0x2)
+	if(IS_HIDDEN(entry))
 		putchar('H');
-	if(entry->dir.attr & 0x1)
+	if(IS_READONLY(entry))
 		putchar('R');
 	if(arg->doPrintName) {
 		putchar(' ');
@@ -99,13 +99,13 @@ static int letterToCode(int letter)
 {
 	switch (toupper(letter)) {
 		case 'A':
-			return 0x20;
+			return ATTR_ARCHIVE;
 		case 'H':
-			return 0x2;
+			return ATTR_HIDDEN;
 		case 'R':
-			return 0x1;
+			return ATTR_READONLY;
 		case 'S':
-			return 0x4;
+			return ATTR_SYSTEM;
 		default:
 			usage();
 	}
