@@ -316,7 +316,7 @@ static int dos_write(direntry_t *entry, MainParam_t *mp, int needfilter)
 	if(entry && arg->preserveAttributes)
 		arg->attr = entry->dir.attr;
 	else
-		arg->attr = 0x20;
+		arg->attr = ATTR_ARCHIVE;
 
 	arg->needfilter = needfilter;
 	if (entry && mp->targetDir == entry->Dir){
