@@ -35,7 +35,7 @@ static int del_entry(direntry_t *entry, MainParam_t *mp)
 		putchar('\n');
 	}
 
-	if ((entry->dir.attr & 0x05) &&
+	if ((entry->dir.attr & (ATTR_READONLY | ATTR_SYSTEM)) &&
 	    (ask_confirmation("%s: \"%s\" is read only, erase anyway (y/n) ? ",
 			      progname, entry->name)))
 		return ERROR_ONE;
@@ -58,7 +58,7 @@ static int del_file(direntry_t *entry, MainParam_t *mp)
 	sonmp = *mp;
 	sonmp.arg = mp->arg;
 
-	if (entry->dir.attr & 0x10){
+	if (IS_DIR(entry)){
 		/* a directory */
 		SubDir = OpenFileByDirentry(entry);
 		initializeDirentry(&subEntry, SubDir);
