@@ -303,7 +303,7 @@ static int list_file(direntry_t *entry, MainParam_t *mp)
 			putchar('\n');
 	}
 	
-	if(entry->dir.attr & 0x10){
+	if(IS_DIR(entry)){
 		size = 0;
 	} else
 		size = FILE_SIZE(&entry->dir);
@@ -324,7 +324,7 @@ static int list_file(direntry_t *entry, MainParam_t *mp)
 	}
 	to_unix(entry->dir.name,8);
 	if(wide){
-		if(entry->dir.attr & 0x10)
+		if(IS_DIR(entry))
 			printf("[%s]%*s", shortname,
 			       (int) (15 - 2 - strlen(shortname)), "");
 		else
@@ -337,7 +337,7 @@ static int list_file(direntry_t *entry, MainParam_t *mp)
 			printf("%-8.8s %-3.3s ",
 			       entry->dir.name, 
 			       entry->dir.ext);
-		if(entry->dir.attr & 0x10)
+		if(IS_DIR(entry))
 			printf("<DIR>    ");
 		else
 			printf(" %8ld", (long) size);
@@ -354,7 +354,7 @@ static int list_file(direntry_t *entry, MainParam_t *mp)
 		printf("\n");
 	} else {
 		printf("%s/%s", dirPath, entry->name);
-		if(entry->dir.attr & 0x10)
+		if(IS_DIR(entry))
 			putchar('/');
 		putchar('\n');
 	}
