@@ -14,6 +14,7 @@
 #ifdef USE_XDF
 #include "xdf_io.h"
 #endif
+#include "partition.h"
 
 #ifndef abs
 #define abs(x) ((x)>0?(x):-(x))
@@ -106,7 +107,7 @@ static void init_geometry_boot(struct bootsector *boot, struct device *dev,
 			boot->jump[0] = 0xeb;
 			boot->jump[1] = 0;
 			boot->jump[2] = 0x90;
-			strncpy(boot->banner, "MTOOLS39", 8);
+			strncpy(boot->banner, "MTOOL391", 8);
 			/* It looks like some versions of DOS are
 			 * rather picky about this, and assume default
 			 * parameters without this, ignoring any
@@ -797,8 +798,17 @@ void mformat(int argc, char **argv, int dummy)
 		read(fd, buf, blocksize);
 		keepBoot = 1;
 	}
-	if(!keepBoot)
+	if(!keepBoot) {
 		memset((char *)boot, '\0', Fs.sector_size);
+		if(Fs.sector_size == 512 && !used_dev.partition) {
+			/* install fake partition table pointing to itself */
+			struct partition *partTable=(struct partition *)
+				(((char*) boot) + 0x1ae);
+			setBeginEnd(&partTable[1], 0,
+						used_dev.heads * used_dev.sectors * used_dev.tracks,
+						used_dev.heads, used_dev.sectors, 1, 0);
+		}
+	}
 	set_dword(boot->nhs, used_dev.hidden);
 
 	Fs.Next = buf_init(Fs.Direct,
