@@ -80,6 +80,7 @@ void minfo(int argc, char **argv, int type)
 		SET_INT(tot_sectors, WORD(psect));
 		printf("device information:\n");
 		printf("===================\n");
+		printf("filename=\"%s\"\n", name);
 		printf("sectors per track: %d\n", dev.sectors);
 		printf("heads: %d\n", dev.heads);
 		printf("cylinders: %d\n\n", dev.tracks);
@@ -92,7 +93,6 @@ void minfo(int argc, char **argv, int type)
 		
 		printf("bootsector information\n");
 		printf("======================\n");
-		printf("filename=\"%s\"\n", name);
 		printf("banner:\"%8s\"\n", boot->banner);
 		printf("sector size: %d bytes\n", WORD(secsiz));
 		printf("cluster size: %d sectors\n", boot->clsiz);
@@ -140,9 +140,25 @@ void minfo(int argc, char **argv, int type)
 		}
 
 		if(verbose) {
+			int size;
+			unsigned char *buf;
+
 			printf("\n");
-			print_sector("Boot sector hexdump", 
-				     (unsigned char*) boot);
+			size = WORD(secsiz);
+			
+			buf = (unsigned char *) malloc(size);
+			if(!buf) {
+				fprintf(stderr, "Out of memory error\n");
+				exit(1);
+			}
+
+			size = READS(Stream, buf, 0, size);
+			if(size < 0) {
+				perror("read boot sector");
+				exit(1);
+			}
+
+			print_sector("Boot sector hexdump", buf, size);
 		}
 	}
 
