@@ -8,6 +8,12 @@
 #include "vfat.h"
 #include "mtools.h"
 
+
+void printOom(void)
+{
+	fprintf(stderr, "Out of memory error");
+}
+
 char *get_homedir(void)
 {
 	struct passwd *pw;
@@ -43,33 +49,47 @@ char *get_homedir(void)
 	return 0;
 }
 
-FILE *open_mcwd(const char *mode)
+
+static void get_mcwd_file_name(char *file)
 {
-	struct stat sbuf;
-	char file[MAXPATHLEN+EXPAND_BUF];
-	time_t now;
 	char *mcwd_path;
 	char *homedir;
 
 	mcwd_path = getenv("MCWD");
 	if (mcwd_path == NULL || *mcwd_path == '\0'){
 		homedir= get_homedir();
-		if ( homedir ){
-			strncpy(file, homedir, MAXPATHLEN);
-			file[MAXPATHLEN]='\0';
-			strcat( file, "/.mcwd");
-		} else
-			strcpy(file,"/tmp/.mcwd");
-	} else
-		expand(mcwd_path,file);
+		if(!homedir)
+			homedir="/tmp";
+		strncpy(file, homedir, MAXPATHLEN-6);
+		file[MAXPATHLEN-6]='\0';
+		strcat( file, "/.mcwd");
+	} else {
+		strncpy(file, mcwd_path, MAXPATHLEN);
+		file[MAXPATHLEN]='\0';
+	}
+}
 
+void unlink_mcwd()
+{
+	char file[MAXPATHLEN+1];
+	get_mcwd_file_name(file);
+	unlink(file);
+}
+
+FILE *open_mcwd(const char *mode)
+{
+	struct stat sbuf;
+	char file[MAXPATHLEN+1];
+	time_t now;
+	
+	get_mcwd_file_name(file);
 	if (*mode == 'r'){
 		if (stat(file, &sbuf) < 0)
 			return NULL;
 		/*
 		 * Ignore the info, if the file is more than 6 hours old
 		 */
-		time(&now);
+		getTimeNow(&now);
 		if (now - sbuf.st_mtime > 6 * 60 * 60) {
 			fprintf(stderr,
 				"Warning: \"%s\" is out of date, removing it\n",
@@ -91,7 +111,7 @@ const char *fix_mcwd(char *ans)
 {
 	FILE *fp;
 	char *s;
-	char buf[BUFSIZ];
+	char buf[MAX_PATH];
 
 	fp = open_mcwd("r");
 	if(!fp){
@@ -99,7 +119,7 @@ const char *fix_mcwd(char *ans)
 		return ans;
 	}
 
-	if (!fgets(buf, BUFSIZ, fp))
+	if (!fgets(buf, MAX_PATH, fp))
 		return("A:/");
 
 	buf[strlen(buf) -1] = '\0';
@@ -136,45 +156,28 @@ const char *fix_mcwd(char *ans)
 	return ans;
 }
 
-size_t maximize(size_t *target, long max)
-{
-	if(max < 0)
-		max = 0;
-	if (*target > max)
-		*target = max;
-	return *target;
-}
-
-size_t minimize(size_t *target, long min)
-{
-	if (*target < min)
-		*target = min;
-	return *target;
-}
-
-
 void *safe_malloc(size_t size)
 {
 	void *p;
 
 	p = malloc(size);
 	if(!p){
-		fprintf(stderr,"Out of memory error\n");
+		printOom();
 		exit(1);
 	}
 	return p;
 }
 
-void print_sector(char *message, unsigned char *data)
+void print_sector(char *message, unsigned char *data, int size)
 {
 	int col;
 	int row;
 
 	printf("%s:\n", message);
 	
-	for(row = 0; row < 32; row++){
+	for(row = 0; row * 16 < size; row++){
 		printf("%03x  ", row * 16);
-		for(col = 0; col < 16; col++)
+		for(col = 0; col < 16; col++)			
 			printf("%02x ", data [row*16+col]);
 		for(col = 0; col < 16; col++) {
 			if(isprint(data [row*16+col]))
@@ -185,3 +188,81 @@ void print_sector(char *message, unsigned char *data)
 		printf("\n");
 	}
 }
+
+
+time_t getTimeNow(time_t *now)
+{
+	static int haveTime = 0;
+	static time_t sharedNow;
+
+	if(!haveTime) {
+		time(&sharedNow);
+		haveTime = 1;
+	}
+	if(now)
+		*now = sharedNow;
+	return sharedNow;
+}
+
+#if 0
+
+#undef free
+#undef malloc
+
+static int total=0;
+
+void myfree(void *ptr)
+{
+	int *size = ((int *) ptr)-1;
+	total -= *size;
+	fprintf(stderr, "freeing %d bytes at %p total alloced=%d\n",
+		*size, ptr, total);
+	free(size);
+}
+
+void *mymalloc(size_t size)
+{
+	int *ptr;
+	ptr = (int *)malloc(size+sizeof(int));
+	if(!ptr)
+		return 0;
+	*ptr = size;
+	ptr++;
+	total += size;
+	fprintf(stderr, "allocating %d bytes at %p total allocated=%d\n",
+		size, ptr, total);
+	return (void *) ptr;
+}
+
+void *mycalloc(size_t nmemb, size_t size)
+{
+	void *ptr = mymalloc(nmemb * size);
+	if(!ptr)
+		return 0;
+	memset(ptr, 0, size);
+	return ptr;
+}
+
+void *myrealloc(void *ptr, size_t size)
+{
+	int oldsize = ((int *)ptr) [-1];
+	void *new = mymalloc(size);
+	if(!new)
+		return 0;
+	memcpy(new, ptr, oldsize);
+	myfree(ptr);
+	return new;
+}
+
+char *mystrdup(char *src)
+{
+	char *dest;
+	dest = mymalloc(strlen(src)+1);
+	if(!dest)
+		return 0;
+	strcpy(dest, src);
+	return dest;
+}
+
+
+#endif
