@@ -60,7 +60,7 @@ int makeit(char *dosname,
 	if (!getfreeMin(targetEntry->Dir, 512))
 		return -1;
 	
-	mk_entry(dosname, 0x10, 1, 0, arg->mtime, &targetEntry->dir);
+	mk_entry(dosname, ATTR_DIR, 1, 0, arg->mtime, &targetEntry->dir);
 	Target = OpenFileByDirentry(targetEntry);
 	if(!Target){
 		fprintf(stderr,"Could not open Target\n");
@@ -73,15 +73,15 @@ int makeit(char *dosname,
 
 	subEntry.entry = 1;
 	GET_DATA(targetEntry->Dir, 0, 0, 0, &fat);
-	mk_entry("..         ", 0x10, fat, 0, arg->mtime, &subEntry.dir);
+	mk_entry("..         ", ATTR_DIR, fat, 0, arg->mtime, &subEntry.dir);
 	dir_write(&subEntry);
 
 	subEntry.entry = 0;
 	GET_DATA(Target, 0, 0, 0, &fat);
-	mk_entry(".          ", 0x10, fat, 0, arg->mtime, &subEntry.dir);
+	mk_entry(".          ", ATTR_DIR, fat, 0, arg->mtime, &subEntry.dir);
 	dir_write(&subEntry);
 
-	mk_entry(dosname, 0x10 | arg->attr, fat, 0, arg->mtime, 
+	mk_entry(dosname, ATTR_DIR | arg->attr, fat, 0, arg->mtime, 
 		 &targetEntry->dir);
 	arg->NewDir = Target;
 	return 0;
@@ -125,9 +125,8 @@ static int createDirCallback(direntry_t *entry, MainParam_t *mp)
 	Stream_t *ret;
 	time_t now;
 
-	ret = createDir(mp->File, mp->targetName, 
-			&((Arg_t *)(mp->arg))->ch, 0x10, 
-			getTimeNow(&now));
+	ret = createDir(mp->File, mp->targetName, &((Arg_t *)(mp->arg))->ch, 
+					ATTR_DIR, getTimeNow(&now));
 	if(ret == NULL)
 		return ERROR_ONE;
 	else {
