@@ -44,7 +44,27 @@ static void set_offset(hsc *h, int offset, int heads, int sectors)
 	h->cyl = cyl & 0xff;
 }
 
-
+void setBeginEnd(struct partition *partTable, int begin, int end,
+				 int heads, int sectors, int activate, int type)
+{
+	set_offset(&partTable->start, begin, heads, sectors);
+	set_offset(&partTable->end, end-1, heads, sectors);
+	set_dword(partTable->start_sect, begin);
+	set_dword(partTable->nr_sects, end-begin);
+	if(activate)
+		partTable->boot_ind = 0x80;
+	else
+		partTable->boot_ind = 0;
+	if(!type) {
+		if(end-begin < 4096)
+			type = 1; /* DOS 12-bit FAT */
+		else if(end-begin<32*2048)
+			type = 4; /* DOS 16-bit FAT, <32M */
+		else
+			type = 6; /* DOS 16-bit FAT >= 32M */
+	}
+	partTable->sys_ind = type;
+}
 
 int consistencyCheck(struct partition *partTable, int doprint, int verbose,
 		     int *has_activated, int *last_end, int *j, 
@@ -438,8 +458,7 @@ void mpartition(int argc, char **argv, int dummy)
 
 	if(initialize) {
 		memset((char *)(partTable+1), 0, 4*sizeof(*partTable));
-		buf[510] = 0x55;
-		buf[511] = 0xaa;
+		set_dword(((char*)buf)+510, 0xaa55);
 	}
 
 	/* check for boot signature, and place it if needed */
@@ -547,25 +566,9 @@ void mpartition(int argc, char **argv, int dummy)
 			exit(1);
 		}
 
-		set_offset(&partTable[dev->partition].start, begin, 
-			   used_dev.heads, used_dev.sectors);
-		set_offset(&partTable[dev->partition].end, end-1, 
-			   used_dev.heads, used_dev.sectors);
-		set_dword(partTable[dev->partition].start_sect, begin);
-		set_dword(partTable[dev->partition].nr_sects, end-begin);
-		if(has_activated)
-			partTable[dev->partition].boot_ind = 0;
-		else
-			partTable[dev->partition].boot_ind = 0x80;
-		if(!type) {
-			if(end-begin < 4096)
-				type = 1; /* DOS 12-bit FAT */
-			else if(end-begin<32*2048)
-				type = 4; /* DOS 16-bit FAT, <32M */
-			else
-				type = 6; /* DOS 16-bit FAT >= 32M */
-		}
-		partTable[dev->partition].sys_ind = type;
+		setBeginEnd(&partTable[dev->partition], begin, end,
+					used_dev.heads, used_dev.sectors, 
+					!has_activated, type);
 	}
 
 	if(activate) {
