@@ -74,6 +74,11 @@ int main(int argc,char **argv)
 	}
 #endif
 
+
+#ifdef __EMX__
+       _wildcard(&argc,&argv);
+#endif 
+
 	/* print the version */
 	if(argc >= 2 && strcmp(argv[1], "-V") == 0) {
 		printf("Mtools version %s, dated %s\n", mversion, mdate);
@@ -116,7 +121,11 @@ int main(int argc,char **argv)
 		return 137;
 	}
 
+#ifdef __EMX__
+       argv[0] = _getname(argv[0]); _remext(argv[0]); name = argv[0];
+#else  
 	name = _basename(argv[0]);
+#endif
 	progname = argv[0];
 
 	/* this allows the different tools to be called as "mtools -c <command>"
