@@ -32,6 +32,10 @@
 #include <scsi/impl/uscsi.h>
 #endif /* sunos */
 
+#ifdef sgi
+#include <sys/dsreq.h>
+#endif
+
 #ifdef OS_linux
 #define SCSI_IOCTL_SEND_COMMAND 1
 struct scsi_ioctl_command {
@@ -168,7 +172,39 @@ int scsi_cmd(int fd, unsigned char *cdb, int cmdlen, scsi_io_mode_t mode,
 		(unsigned)scsi_cmd.host_sts,(unsigned)scsi_cmd.target_sts);
 		return -1;
 	}
-	return 0;	
+	return 0;
+#elif defined sgi
+ 	struct dsreq scsi_cmd;
+
+	scsi_cmd.ds_cmdbuf = (char *)cdb;
+	scsi_cmd.ds_cmdlen = cmdlen;
+	scsi_cmd.ds_databuf = data;
+	scsi_cmd.ds_datalen = len;
+       	switch (mode) {
+	case SCSI_IO_READ:
+	  scsi_cmd.ds_flags = DSRQ_READ|DSRQ_SENSE;
+	  break;
+	case SCSI_IO_WRITE:
+	  scsi_cmd.ds_flags = DSRQ_WRITE|DSRQ_SENSE;
+	  break;
+        } 
+	scsi_cmd.ds_time = 10000;
+	scsi_cmd.ds_link = 0;
+	scsi_cmd.ds_synch =0;
+	scsi_cmd.ds_ret =0;
+	if (ioctl(fd, DS_ENTER, &scsi_cmd) == -1) {
+                perror("scsi_io");
+                return -1;
+        }
+
+        if(scsi_cmd.ds_status) {
+                errno = 0;
+                fprintf(stderr,"scsi status=%x\n",  
+                        (unsigned short)scsi_cmd.ds_status);
+                return -1;
+        }
+        
+        return 0;
 #else
 	fprintf(stderr, "scsi_io not implemented\n");
 	return -1;
