@@ -1,3 +1,7 @@
+#ifndef __mtools_scsi_h
+#define __mtools_scsi_h
+
+
 #define SCSI_READ 0x8
 #define SCSI_WRITE 0xA
 #define SCSI_IOMEGA 0xC
@@ -13,3 +17,5 @@ typedef enum { SCSI_IO_READ, SCSI_IO_WRITE } scsi_io_mode_t;
 int scsi_max_length(void);
 int scsi_cmd(int fd, unsigned char cdb[6], int clen, scsi_io_mode_t mode,
 	     void *data, size_t len);
+
+#endif /* __mtools_scsi_h */
