@@ -2,14 +2,17 @@
 #include "msdos.h"
 #include "stream.h"
 
+int batchmode = 0;
+
 int flush_stream(Stream_t *Stream)
 {
 	int ret=0;
-
-	if(Stream->Class->flush)
-		ret |= Stream->Class->flush(Stream);
-	if(Stream->Next)
-		ret |= flush_stream(Stream->Next);
+	if(!batchmode) {
+		if(Stream->Class->flush)
+			ret |= Stream->Class->flush(Stream);
+		if(Stream->Next)
+			ret |= flush_stream(Stream->Next);
+	}
 	return ret;
 }
 
@@ -26,11 +29,11 @@ int free_stream(Stream_t **Stream)
 
 	if(!*Stream)
 		return -1;
-	if((*Stream)->Class->flush)
-		ret |= (*Stream)->Class->flush(*Stream);
 	if(! --(*Stream)->refs){
-		if((*Stream)->Class->free)
-			ret |= (*Stream)->Class->free(*Stream);
+		if((*Stream)->Class->flush)
+			ret |= (*Stream)->Class->flush(*Stream);
+		if((*Stream)->Class->freeFunc)
+			ret |= (*Stream)->Class->freeFunc(*Stream);
 		if((*Stream)->Next)
 			ret |= free_stream(&(*Stream)->Next);
 		Free(*Stream);
