@@ -15,17 +15,18 @@ typedef struct Class_t {
 	int (*read)(Stream_t *, char *, off_t, size_t);
 	int (*write)(Stream_t *, char *, off_t, size_t);
 	int (*flush)(Stream_t *);
-	int (*free)(Stream_t *);
+	int (*freeFunc)(Stream_t *);
 	int (*set_geom)(Stream_t *, device_t *, device_t *, int media,
 			struct bootsector *);
 	int (*get_data)(Stream_t *, long *, size_t *, int *, int *);
+	int (*pre_allocate)(Stream_t *, size_t);
 } Class_t;
 
-#define READS(stream, buf, address, data) \
-(stream)->Class->read( (stream), (char *) (buf), (address), (data) )
+#define READS(stream, buf, address, size) \
+(stream)->Class->read( (stream), (char *) (buf), (address), (size) )
 
-#define WRITES(stream, buf, address, data) \
-(stream)->Class->write( (stream), (char *) (buf), (address), (data) )
+#define WRITES(stream, buf, address, size) \
+(stream)->Class->write( (stream), (char *) (buf), (address), (size) )
 
 #define SET_GEOM(stream, dev, orig_dev, media, boot) \
 (stream)->Class->set_geom( (stream), (dev), (orig_dev), (media), (boot) )
@@ -33,6 +34,8 @@ typedef struct Class_t {
 #define GET_DATA(stream, date, size, type, address) \
 (stream)->Class->get_data( (stream), (date), (size), (type), (address) )
 
+#define PRE_ALLOCATE(stream, size) \
+(stream)->Class->pre_allocate((stream), (size))
 
 int flush_stream(Stream_t *Stream);
 Stream_t *copy_stream(Stream_t *Stream);
@@ -60,5 +63,7 @@ int get_data_pass_through(Stream_t *Stream, long *date, size_t *size,
 
 int read_pass_through(Stream_t *Stream, char *buf, off_t start, size_t len);
 int write_pass_through(Stream_t *Stream, char *buf, off_t start, size_t len);
+
+
 #endif
 
