@@ -5,6 +5,13 @@
 
 #include "config.h"
 
+/* OS/2 needs __inline__, but for some reason is not autodetected */
+#ifdef __EMX__
+# ifndef inline
+#  define inline __inline__
+# endif
+#endif
+
 /***********************************************************************/
 /*                                                                     */
 /* OS dependancies which cannot be covered by the autoconfigure script */
@@ -235,10 +242,6 @@ extern int errno;
 # include <sys/wait.h>
 #endif
 
-#ifdef OS_linux
-# include <linux/fd.h>
-#endif
-
 #ifdef sgi
 #define MSGIHACK __EXTENSIONS__
 #undef __EXTENSIONS__
