@@ -507,7 +507,7 @@ static result_t checkNameForMatch(struct direntry_t *direntry,
 
 	/* entry of non-requested type, has to come after name
 	 * checking because of clash handling */
-	if((direntry->dir.attr & 0x10) && !(flags & ACCEPT_DIR)) {
+	if(IS_DIR(direntry) && !(flags & ACCEPT_DIR)) {
 		if(!(flags & (ACCEPT_LABEL|MATCH_ANY|NO_MSG)))
 			fprintf(stderr,
 				"Skipping \"%s\", is a directory\n",
@@ -515,7 +515,8 @@ static result_t checkNameForMatch(struct direntry_t *direntry,
 		return RES_NOMATCH;
 	}
 
-	if((!(direntry->dir.attr & 0x18)) && !(flags & ACCEPT_PLAIN)) {
+	if(!(direntry->dir.attr & (ATTR_LABEL | ATTR_DIR)) && 
+	   !(flags & ACCEPT_PLAIN)) {
 		if(!(flags & (ACCEPT_LABEL|MATCH_ANY|NO_MSG)))
 			fprintf(stderr,
 				"Skipping \"%s\", is not a directory\n",
@@ -604,16 +605,33 @@ static inline dirCacheEntry_t *vfat_lookup_loop_for_insert(direntry_t *direntry,
 	}
 }
 
+static void accountFreeSlots(struct scan_state *ssp, dirCacheEntry_t *dce)
+{
+	if(ssp->got_slots)
+		return;
+
+	if(ssp->free_end != dce->beginSlot) {
+		ssp->free_start = dce->beginSlot;
+	}
+	ssp->free_end = dce->endSlot;
+
+	if(ssp->free_end - ssp->free_start > ssp->size_needed) {
+		ssp->got_slots = 1;
+		ssp->slot = ssp->free_start + ssp->size_needed - 1;
+	}
+}
+
 /* lookup_for_insert replaces the old scandir function.  It directly
  * calls into vfat_lookup_loop, thus eliminating the overhead of the
  * normal vfat_lookup
  */
 int lookupForInsert(Stream_t *Dir,
-		    char *dosname,
-		    char *longname,
-		    struct scan_state *ssp, 
-		    int ignore_entry,
-		    int pessimisticShortRename)
+					char *dosname,
+					char *longname,
+					struct scan_state *ssp, 
+					int ignore_entry,
+					int source_entry,
+					int pessimisticShortRename)
 {
 	direntry_t entry;
 	int ignore_match;
@@ -640,7 +658,8 @@ int lookupForInsert(Stream_t *Dir,
 		unix_name(dosname, dosname + 8, 0, shortName);
 
 	pos = cache->nrHashed;
-	if(pos && isHashed(cache, longname)) {
+	if(source_entry >= 0 ||
+	   (pos && isHashed(cache, longname))) {
 		pos = 0;
 	} else if(pos && !ignore_match && isHashed(cache, shortName)) {
 		if(pessimisticShortRename) {
@@ -656,17 +675,13 @@ int lookupForInsert(Stream_t *Dir,
 		dce = vfat_lookup_loop_for_insert(&entry, pos, cache);
 		switch(dce->type) {
 			case DCET_FREE:
-				if(!ssp->got_slots && 
-				   dce->endSlot - dce->beginSlot > 
-				   ssp->size_needed) {
-					ssp->got_slots = 1;
-					ssp->free_start = dce->beginSlot;
-					ssp->slot = ssp->free_start + 
-						ssp->size_needed - 1;
-					ssp->free_end = dce->endSlot;
-				}
+				accountFreeSlots(ssp, dce);
 				break;
 			case DCET_USED:
+				if(!(dce->dir.attr & 0x8) &&
+				   dce->endSlot - 1 == source_entry)
+				   accountFreeSlots(ssp, dce);
+
 				/* labels never match, neither does the 
 				 * ignored entry */
 				if( (dce->dir.attr & 0x8) ||
