@@ -396,7 +396,7 @@ static void decompose(Xdf_t *This, int where, int len, off_t *begin, off_t *end,
 	
 	*begin = where - track * This->track_size * 1024;
 	*end = where + len - track * This->track_size * 1024;
-	maximize((size_t *)end, This->track_size * 1024);
+	maximize(*end, This->track_size * 1024);
 
 	if(This->current_track == track && !boot)
 		/* already OK, return immediately */
@@ -476,7 +476,7 @@ static int xdf_read(Stream_t *Stream, char *buf, off_t where, size_t len)
 	if(len2 < 0)
 		return len2;
 	len2 -= begin;
-	maximize(&len, len2);
+	maximize(len, len2);
 	memcpy(buf, This->buffer + begin, len);
 	return end - begin;
 }
@@ -491,9 +491,9 @@ static int xdf_write(Stream_t *Stream, char *buf, off_t where, size_t len)
 	len2 = load_bounds(This, begin, end);
 	if(len2 < 0)
 		return len2;
-	maximize((size_t *)&end, len2);
+	maximize(end, len2);
 	len2 -= begin;
-	maximize(&len, len2);
+	maximize(len, len2);
 	memcpy(This->buffer + begin, buf, len);
 	mark_dirty(This, begin, end);
 	return end - begin;
@@ -573,7 +573,8 @@ static Class_t XdfClass = {
 	xdf_flush, 
 	xdf_free, 
 	config_geom, 
-	0 /* get_data */
+	0, /* get_data */
+	0 /* pre-allocate */
 };
 
 Stream_t *XdfOpen(struct device *dev, char *name,
@@ -584,7 +585,7 @@ Stream_t *XdfOpen(struct device *dev, char *name,
 	struct bootsector *boot;
 	int type;
 
-	if(dev && (!dev->use_xdf || check_geom(dev, 0, 0)))
+	if(dev && (!SHOULD_USE_XDF(dev) || check_geom(dev, 0, 0)))
 		return NULL;
 
 	This = New(Xdf_t);
